from string import Template


class AutoAlbumentTemplate(Template):
    delimiter = "@@"
